The Python module ``syglass`` allows scientists and developers alike to create powerful custom workflows to leverage their `syGlass <https://www.syglass.io/>`_ image volumes and annotations.

For documentation, examples, and installation resources please visit https://istovisio.github.io/. Feel free to contact us at info@syglass.io for questions, bug reports, or requests!